@@ -1,10 +1,11 @@
-from blah.fetcher import fetch
+from blah.fetcher import fetch, archive
 from blah.repositories import find_repository, repository_at
 from blah.errors import UnrecognisedSourceControlSystem
 from blah.systems import is_source_control_uri
 
 __all__ = [
     "fetch",
+    "archive",
     "find_repository",
     "repository_at",
     "is_source_control_uri",
